beamprofiler.beam
=================

.. automodule:: beamprofiler.beam

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class.rst
   
      Beam
   
   

   
   
   



